@@ -1,24 +1,7 @@
 <!-- Layers Menu (c) 2001 Marco Pratesi <pratesi@telug.it> -->
 
-<script language="JavaScript1.2">
-<!--
-if (NS4) {
-	gotlayers = (document.layers.length == 3) ? 1 : 0;
-}
-if (IE4) {
-	gotlayers = 1;
-}
-// -->
-</script>
-
-<script language="JavaScript1.3">
-<!--
-	gotlayers = 1;
-// -->
-</script>
-
 <?
-for ($cnt=1; $cnt<count($tree); $cnt++)
+for ($cnt=1; $cnt<=count($tree); $cnt++)
 	if (!($tree[$cnt+1][0]<=$tree[$cnt][0])) {
 $cellpadding = 10;
 $width = $abscissa_step - $cellpadding;
@@ -32,7 +15,7 @@ $width = $abscissa_step - $cellpadding;
 <table border=0 cellpadding=0 cellspacing=<?=$cellpadding?> width="<?=$abscissa_step?>">
 <tr>
 <td class=normal nowrap>
-<b><?=$tree[$cnt][1]?></b>
+<b><?=stripslashes($tree[$cnt][1])?></b>
 </td>
 </tr>
 <tr>
@@ -48,4 +31,11 @@ $width = $abscissa_step - $cellpadding;
 
 <?	} ?>
 
+<script language="JavaScript">
+<!--
+	gotlayers = 1;	// to avoid stupid errors of Microsoft browsers
+	moveLayers();
+// -->
+</script>
+
 <!-- Layers Menu (c) 2001 Marco Pratesi <pratesi@telug.it> -->
