@@ -277,7 +277,7 @@ function import_brands($userfile) {
 
 		/* ... and let's see if the brand already exists ... */
 		$qid = db_query("
-		SELECT id, name FROM brands WHERE name = '$fldarr[0]'
+		SELECT id FROM brands WHERE name = '$fldarr[0]'
 		");
 		if (db_num_rows($qid) == 0) {
 			/* ... if it doesn't exist let's create it ... */
