@@ -74,7 +74,7 @@ switch (nvl($mode)) {
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = $Add_Subcategory;
 			/* build the categories listbox options, preselect the selected item */
-			build_category_tree($category_options, $frm["parent"]);
+			build_category_tree(&$category_options, $frm["parent"]);
 			include("$CFG->templatedir"."form_header.ihtml");
 			include("templates/category_form.ihtml");
 		}
@@ -105,7 +105,7 @@ switch (nvl($mode)) {
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["submit_caption"] = $Save_Changes;
 			/* build the categories listbox options, preselect the selected item */
-			build_category_tree($category_options, $frm["parent"]);
+			build_category_tree(&$category_options, $frm["parent"]);
 			include("$CFG->templatedir"."form_header.ihtml");
 			include("templates/category_form.ihtml");
 		}
@@ -151,7 +151,7 @@ function print_add_category_form($id) {
 	$frm["submit_caption"] = $Add_Subcategory;
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree($category_options, $frm["parent"]);
+	build_category_tree(&$category_options, $frm["parent"]);
 
 	include("templates/category_form.ihtml");
 }
@@ -177,7 +177,7 @@ function print_edit_category_form($id) {
 	$frm["submit_caption"] = $Save_Changes;
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree($category_options, $frm["parent"]);
+	build_category_tree(&$category_options, $frm["parent"]);
 
 	include("templates/category_form.ihtml");
 }
