@@ -96,8 +96,10 @@ function update_user_password($newpassword, $username) {
 	$qid = db_query("UPDATE users
 			SET password = '$newpassword'
 			WHERE username = '$username'");
+	$qid = db_query("SELECT priv FROM users WHERE username = '$username'");
+	$appoggio = db_fetch_array($qid, 0);
 
-	if (has_priv("admin")) {
+	if ($appoggio == "admin") {
 		mail(
 			"$CFG->seller_fullname <$CFG->seller_email>",
 			"PgMarket root password changed",
