@@ -97,7 +97,7 @@ switch (nvl($mode)) {
 			$frm["extended_description"] = $HTTP_POST_VARS["extended_description"];
 			$frm["submit_caption"] = $Add_Product;
 			/* build the categories listbox options, preselect the top item */
-			build_category_tree($category_options, $frm["categories"]);
+			build_category_tree(&$category_options, $frm["categories"]);
 			include("$CFG->templatedir"."form_header.ihtml");
 			include("templates/product_form.ihtml");
 		}
@@ -164,7 +164,7 @@ switch (nvl($mode)) {
 			$frm["delete_image"] = $HTTP_POST_VARS["delete_image"];
 			$frm["submit_caption"] = $Save_Changes;
 			/* build the categories listbox options, preselect the top item */
-			build_category_tree($category_options, $frm["categories"]);
+			build_category_tree(&$category_options, $frm["categories"]);
 			include("$CFG->templatedir"."form_header.ihtml");
 			include("templates/product_form.ihtml");
 		}
@@ -260,7 +260,7 @@ function print_add_product_form($category_id = 1) {
 	}
 
 	/* build the categories listbox options, preselect the top item */
-	build_category_tree($category_options, $frm["categories"]);
+	build_category_tree(&$category_options, $frm["categories"]);
 
 	include("templates/product_form.ihtml");
 }
@@ -329,7 +329,7 @@ function print_edit_product_form($product_id) {
 	$frm["submit_caption"] = $Save_Changes;
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree($category_options, $frm["categories"]);
+	build_category_tree(&$category_options, $frm["categories"]);
 
 	include("templates/product_form.ihtml");
 }
@@ -365,7 +365,7 @@ function print_details_product($product_id) {
 	}
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree($category_options, $frm["categories"]);
+	build_category_tree(&$category_options, $frm["categories"]);
 
 	include("templates/product_details.ihtml");
 }
@@ -966,7 +966,7 @@ function import_images($HTTP_POST_FILES) {
 			}
 			if ($type != "") {
 				$upload_name_thumb = $upload_name.".thumb.jpg";
-				$upload_name_old = $upload_name.".".$oldtype;
+				$upload_name_old = $upload_name;
 				$upload_name .= ".".$type;
 				if (!copy($tmpdir.$file, $upload_name)) {
 					echo "<div class=normal>" . $image_upload_failed . "</div>";
@@ -983,7 +983,7 @@ function import_images($HTTP_POST_FILES) {
 					$arr = db_fetch_array($qid, 0);
 					$oldtype = $arr["imagetype"];
 					if ($type != $oldtype) {
-						system ("rm -f ".$upload_name_old, $result);
+						system ("rm -f ".$upload_name_old.".".$oldtype, $result);
 					}
 
 					$qid = db_query("
