@@ -5,7 +5,7 @@
 
 <html>
 <frameset cols="180,*" framespacing=0 frameborder=no border=0>
-<frame name="categories" src="shopping/navigation.php?p=0" target="bodyframe">
+<frame name="categories" src="shopping/navigation.php" target="bodyframe">
 <frame name="bodyframe" src="<?=$CFG->firstpage?>">
 </frameset>
 </html>
