@@ -4,7 +4,7 @@
 $abscissa_step = 140;			// step for the left boundaries of layers
 $abscissa_stepx5 = $abscissa_step*5;
 $ordinata_step = 15;			// estimated value of the number of pixels between links on a layer
-$ordinata[2] = 200-$ordinata_step;	// to choose the vertical coordinate start offset for the layers
+$ordinata[1] = 200-$ordinata_step;	// to choose the vertical coordinate start offset for the layers
 $rightarrow = " &middot;&middot;&middot;&gt;";
 ?>
 
@@ -13,7 +13,7 @@ $rightarrow = " &middot;&middot;&middot;&gt;";
 NS4 = (document.layers) ? 1 : 0;
 IE4 = (document.all) ? 1 : 0;
 DOM = (document.getElementById) ? 1 : 0;
-var gotlayers = 0;
+var gotlayers = 0;	// to avoid stupid errors of Microsoft browsers
 var lastbutton='top';
 // -->
 </script>
@@ -22,14 +22,14 @@ var lastbutton='top';
 <!--
 
 function popUp(menuName,on) {
-	if (gotlayers) {
+	if (gotlayers) {	// to avoid stupid errors of Microsoft browsers
 		if (on) {
-			moveLayers();
+//			moveLayers();
 			if (NS4) {
 				document.layers[menuName].visibility = "show";
 			} else if (DOM) {
 				document.getElementById(menuName).style.visibility = "visible";
-                        } else {
+			} else {
 				document.all[menuName].style.visibility = "visible";
 			}
 		} else {
@@ -47,7 +47,6 @@ function popUp(menuName,on) {
 <?
 
 build_catbrowser_js($categories);
-$categories = ".Top^" . $CFG->wwwroot . "/shopping/\n" . $categories;
 //echo $categories;
 
 $moveLayersNS4 = "";
@@ -56,10 +55,11 @@ $moveLayersDef = "";
 $shutdown = "";
 $firstleveltable = "";
 
-// Taken from TreeMenu 1.0 (c) 1999 by Bjorge Dijkstra - bjorge@gmx.net
+// Taken from TreeMenu 1.1 - Bjorge Dijkstra (bjorge@gmx.net)
+// with some changes
 
 $maxlevel=0;
-$cnt=0;
+$cnt=1;
 
 while ($categories != "") {
 	$beforecr = strcspn($categories,"\n");
@@ -69,7 +69,7 @@ while ($categories != "") {
 	$tmp=rtrim(substr($buffer,$tree[$cnt][0]));
 	$node=explode("^",$tmp);
 	$tree[$cnt][1]=$node[0];
-	$stripped_tree[$cnt] = string_cleanup_js($tree[$cnt][1]) . $cnt;
+	$stripped_tree[$cnt] = "L" . $cnt;
 	$tree[$cnt][2]=$node[1];
 	$tree[$cnt][3]=$node[2];
 	$tree[$cnt][4]=0;
@@ -82,7 +82,7 @@ while ($categories != "") {
 for ($i=0; $i<$maxlevel; $i++)
 	$abscissa[$i] = $i * $abscissa_step;
 
-for ($cnt=1; $cnt<count($tree); $cnt++) {	// this counter scans all nodes
+for ($cnt=1; $cnt<=count($tree); $cnt++) {	// this counter scans all nodes
 	// assign the layers name to the current hierarchical level,
 	// to keep trace of the route leading to the current node on the tree
 	$layername[$tree[$cnt][0]] = $stripped_tree[$cnt];
@@ -97,17 +97,17 @@ for ($cnt=1; $cnt<count($tree); $cnt++) {	// this counter scans all nodes
 	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// the node is not a leaf, hence it has at least a child
 		// prepare the popUp function related to the children
 		echo "function popUp" . $stripped_tree[$cnt] . "() {\n" . "shutdown();\n";
-		for ($i=2; $i<=$tree[$cnt][0]; $i++)
+		for ($i=1; $i<=$tree[$cnt][0]; $i++)
 			echo "popUp('" . $layername[$i] . "',true);\n";
 		echo "}\n";
 
 		// geometrical parameters are assigned to the new layer, related to the above mentioned children
-		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
+		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]] . ";\n";
 		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
-		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
+		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]] . ";\n";
 		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
 		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.width = " . $abscissa_step . ";\n";
-		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
+		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]] . ";\n";
 		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
 		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";
 
@@ -115,7 +115,7 @@ for ($cnt=1; $cnt<count($tree); $cnt++) {	// this counter scans all nodes
 		$shutdown .= "popUp('" . $stripped_tree[$cnt] . "',false);\n"; 
 	}
 
-	if ($tree[$cnt][0] > 2) {	// the hierarchical level is > 2, hence the current node is not a child of the root node
+	if ($tree[$cnt][0] > 1) {	// the hierarchical level is > 1, hence the current node is not a child of the root node
 		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
 /* */
 		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
@@ -134,7 +134,7 @@ for ($cnt=1; $cnt<count($tree); $cnt++) {	// this counter scans all nodes
 */
 	}
 
-	if ($tree[$cnt][0] == 2) {	// the hierarchical level is = 2, hence the current node is a child of the root node
+	if ($tree[$cnt][0] == 1) {	// the hierarchical level is = 1, hence the current node is a child of the root node
 		// handle accordingly the corresponding link, distinguishing if the current node is a leaf or not
 		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {	// not a leaf
 			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . stripslashes($tree[$cnt][1]) . "</a>" . $rightarrow . "<br>\n";
@@ -151,7 +151,7 @@ $shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocumen
 ?>
 
 function moveLayers() {
-if (gotlayers) {
+if (gotlayers) {	// to avoid stupid errors of Microsoft browsers
 if (NS4) {
 <?=$moveLayersNS4?>
 } else if (DOM) {
