@@ -90,12 +90,12 @@ function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
 		$selected = in_array($cat->id, $preselected) ? "selected" : "";
 		$output .= "<option value=\"" . ov($cat->id) . "\" $selected>" . $indent . ov($cat->name);
 		if ($cat->id != $parent) {
-			build_category_tree($output, $preselected, $cat->id, $indent."&nbsp;&nbsp;");
+			build_category_tree(&$output, $preselected, $cat->id, $indent."&nbsp;&nbsp;");
 		}
 	}
 }
 
-function build_catbrowser(&$output, $parent=1, $indent="..") {
+function build_catbrowser(&$output, $parent=1, $indent=".") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
@@ -115,7 +115,7 @@ function build_catbrowser(&$output, $parent=1, $indent="..") {
 	}
 }
 
-function build_catbrowser_js(&$output, $parent=1, $indent="..") {
+function build_catbrowser_js(&$output, $parent=1, $indent=".") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
