@@ -17,7 +17,7 @@
 function setdefault(&$var, $default="") {
 /* if $var is undefined, set it to $default.  otherwise leave it alone */
 
-	if (! isset($var)) {
+	if (empty($var)) {
 		$var = $default;
 	}
 }
@@ -28,7 +28,7 @@ function nvl(&$var, $default="") {
 	return isset($var) ? $var : $default;
 }
 
-function ov(&$var) {
+function ov($var) {
 /* returns $var with the HTML characters (like "<", ">", etc.) properly quoted,
  * or if $var is undefined, will return an empty string.  note this function
  * must be called with a variable, for normal strings or functions use o() */
@@ -36,7 +36,7 @@ function ov(&$var) {
 	return isset($var) ? htmlSpecialChars(stripslashes($var)) : "";
 }
 
-function pv(&$var) {
+function pv($var) {
 /* prints $var with the HTML characters (like "<", ">", etc.) properly quoted,
  * or if $var is undefined, will print an empty string.  note this function
  * must be called with a variable, for normal strings or functions use p() */
@@ -44,7 +44,7 @@ function pv(&$var) {
 	echo isset($var) ? htmlSpecialChars(stripslashes($var)) : "";
 }
 
-function pvwbr(&$var) {
+function pvwbr($var) {
 /* prints $var with the HTML characters (like "<", ">", etc.) properly quoted,
  * or if $var is undefined, will print an empty string.  note this function
  * must be called with a variable, for normal strings or functions use p() */
@@ -171,7 +171,7 @@ function redirect($url, $message="", $delay=0) {
 	die;
 }
 
-function read_template($filename, &$var) {
+function read_template($filename, $var) {
 /* return a (big) string containing the contents of a template file with all
  * the variables interpolated.  all the variables must be in the $var[] array or
  * object (whatever you decide to use).
@@ -245,43 +245,4 @@ function string_cleanup ($string) {
 
 }
 
-function string_cleanup_js ($string) {
-// "cleans up" a string containing "strange" characters
-
-	$string = str_replace(" ", "space", $string);
-	$string = str_replace("-", "minus", $string);
-	$string = str_replace("!", "exclam", $string);
-	$string = str_replace("", "sterling", $string);
-	$string = str_replace("$", "dollar", $string);
-	$string = str_replace("%", "percent", $string);
-	$string = str_replace("&", "ampersand", $string);
-	$string = str_replace("/", "slash", $string);
-	$string = str_replace("\\", "backslash", $string);
-	$string = str_replace("(", "parenleft", $string);
-	$string = str_replace(")", "parenright", $string);
-	$string = str_replace("[", "bracketleft", $string);
-	$string = str_replace("]", "bracketright", $string);
-	$string = str_replace("{", "braceleft", $string);
-	$string = str_replace("}", "braceright", $string);
-	$string = str_replace("?", "question", $string);
-	$string = str_replace("*", "asterisk", $string);
-	$string = str_replace("@", "at", $string);
-	$string = str_replace("", "paragraph", $string);
-	$string = str_replace(">", "greater", $string);
-	$string = str_replace("<", "lower", $string);
-	$string = str_replace("", "degree", $string);
-	$string = str_replace("#", "numbersign", $string);
-	$string = str_replace("~", "tilde", $string);
-	$string = str_replace("`", "grave", $string);
-	$string = str_replace("'", "apostrophe", $string);
-	$string = str_replace("", "cedilla", $string);
-	$string = str_replace(",", "comma", $string);
-	$string = str_replace(".", "dot", $string);
-	$string = str_replace(";", "dotcomma", $string);
-	$string = str_replace(":", "dotdot", $string);
-
-	return $string;
-
-}
-
 ?>
