@@ -1,10 +1,12 @@
-<?
+<?php
   /*********************************************/
-  /*  PHP3 TreeMenu                            */
+  /*  PHP TreeMenu 1.1                         */
   /*                                           */
-  /*  (c)1999 Bjorge Dijkstra                  */
+  /*  Author: Bjorge Dijkstra                  */
   /*  email : bjorge@gmx.net                   */
   /*                                           */  
+  /*  Placed in Public Domain                  */  
+  /*                                           */  
   /*********************************************/
 
   /*********************************************/
@@ -16,8 +18,18 @@
   /*                                           */ 
   /*********************************************/
   
-  $script       = $SCRIPT_NAME;
-  
+  /*********************************************/
+  /*                                           */
+  /* - Multiple root node fix by Dan Howard    */
+  /*                                           */
+  /*********************************************/
+
+  if(isset($PATH_INFO)) {
+	  $script = $PATH_INFO;
+  } else {
+	  $script = $SCRIPT_NAME;
+  }
+
   $img_expand   = $CFG->images . "tree_expand.gif";
   $img_collapse = $CFG->images . "tree_collapse.gif";
   $img_line     = $CFG->images . "tree_vertline.gif";  
@@ -25,6 +37,7 @@
   $img_end      = $CFG->images . "tree_end.gif";
   $img_leaf     = $CFG->images . "tree_leaf.gif";
   $img_spc      = $CFG->images . "tree_space.gif";
+
   
   /*********************************************/
   /*  Read text file with tree structure       */
@@ -48,7 +61,7 @@
 //  {
 /////////////////////////////////////////////////////////
 // { begin Marco Pratesi
-//$categories = ".Menu\n..About|about.html|main\n..<b>Demo menu</b>|javascript: alert('This is the demo menu for TreeMenu 1.0');\n...Menu Structure File|demomenu.txt|main\n...Script source|demo.phps|main\n...<b>category 1</b>\n....<b>sub category 1.1</b>\n.....item 1.1.1|javascript: alert('Item 1.1.1');\n.....item 1.1.2|javascript: alert('Item 1.1.1');\n....item 1.2|javascript: alert('Item 1.2');\n....item 1.3|javascript: alert('Item 1.3');\n...<b>category 2</b>\n....item 2.1|javascript: alert('Item 2.1');\n....item 2.2|javascript: alert('Item 2.2');\n....<b>sub category 2.3</b>\n.....item 2.3.1|javascript: alert('Item 2.3.1');\n.....item 2.3.2|javascript: alert('Item 2.3.2');\n..<i><b>Email me</b></i>|mailto:bjorge@gmx.net?subject=Tree%20Menu%20Demo\n";
+//$categories = ".About|about.html|main\n.<b>Demo menu</b>|javascript: alert('This is the demo menu for TreeMenu 1.0');\n..<b>category 1</b>\n...<b>sub category 1.1</b>\n....item 1.1.1|javascript: alert('Item 1.1.1');\n....item 1.1.2|javascript: alert('Item 1.1.1');\n...item 1.2|javascript: alert('Item 1.2');\n...item 1.3|javascript: alert('Item 1.3');\n..<b>category 2</b>\n...item 2.1|javascript: alert('Item 2.1');\n...item 2.2|javascript: alert('Item 2.2');\n...<b>sub category 2.3</b>\n....item 2.3.1|javascript: alert('Item 2.3.1');\n....item 2.3.2|javascript: alert('Item 2.3.2');\n.<i><b>Download</b></i>|treemenu11.zip\n.<i><b>Email me</b></i>|mailto:bjorge@gmx.net?subject=Tree%20Menu%20Demo\n";
 // "|" has been replaced by "^" in $categories
   while ($categories != "") {
     $beforecr = strcspn($categories,"\n");
@@ -77,7 +90,7 @@
   /*********************************************/
   /*  Get Node numbers to expand               */
   /*********************************************/
-  
+
   if ($p!="") $explevels = explode("|",$p);
   
   $i=0;
@@ -116,8 +129,11 @@
   /*  Determine visible nodes                  */
   /*********************************************/
   
-  $visible[0]=1;   // root is always visible
-  for ($i=0; $i<count($explevels); $i++)
+// all root nodes are always visible
+  for ($i=0; $i < count($tree); $i++) if ($tree[$i][0]==1) $visible[$i]=1;
+
+
+  for ($i=0; $i < count($explevels); $i++)
   {
     $n=$explevels[$i];
     if ( ($visible[$n]==1) && ($expand[$n]==1) )
@@ -140,10 +156,11 @@
 
   $maxlevel++;
   
-  echo "<table cellspacing=0 cellpadding=0 border=0 cols=".($maxlevel+3)." width=".($maxlevel*16+100).">\n";
+  echo "<table cellspacing=0 cellpadding=0 border=0 cols=".($maxlevel+3)." width=100%>\n";
   echo "<tr>";
-  for ($i=0; $i<$maxlevel; $i++) echo "<td width=16></td>";
-  echo "<td width=100></td></tr>\n";
+  for ($i=0; $i<$maxlevel; $i++) echo "<td width=\"16\"></td>";
+//  echo "<td width=100%>&nbsp;</td></tr>\n";
+  echo "<td width=100%></td></tr>\n";
   $cnt=0;
   while ($cnt<count($tree))
   {
@@ -161,9 +178,9 @@
       while ($i<$tree[$cnt][0]-1) 
       {
         if ($levels[$i]==1)
-            echo "<td><img src=\"".$img_line."\"></td>";
+            echo "<td><a name='$cnt'></a><img src=\"".$img_line."\"></td>";
         else
-            echo "<td><img src=\"".$img_spc."\"></td>";
+            echo "<td><a name='$cnt'></a><img src=\"".$img_spc."\"></td>";
         $i++;
       }
       
@@ -202,9 +219,9 @@
         }
                
         if ($expand[$cnt]==0)
-            echo "<td nowrap><a href=\"".$script.$params."\"><img src=\"".$img_expand."\" border=no></a></td>";
+            echo "<td><a href=\"".$script.$params."#$cnt\"><img src=\"".$img_expand."\" border=no></a></td>";
         else
-            echo "<td nowrap><a href=\"".$script.$params."\"><img src=\"".$img_collapse."\" border=no></a></td>";
+            echo "<td><a href=\"".$script.$params."#$cnt\"><img src=\"".$img_collapse."\" border=no></a></td>";
       }
       else
       {
@@ -232,30 +249,4 @@
     $cnt++;    
   }
   echo "</table>\n";
-
-  /***************************************************/
-  /* Tree file format                                */
-  /*                                                 */
-  /*                                                 */
-  /* The first line is always of format :            */
-  /* .[rootname]                                     */
-  /*                                                 */
-  /* each line contains one item, the line starts    */ 
-  /* with a series of dots(.). Each dot is one level */
-  /* deeper. Only one level at a time once is allowed*/
-  /* Next comes the come the item name, link and     */
-  /* link target, seperated by a |.                  */
-  /*                                                 */  
-  /* example:                                        */
-  /*                                                 */  
-  /* .top                                            */
-  /* ..category 1                                    */
-  /* ...item 1.1|item11.htm|main                     */
-  /* ...item 2.2|item12.htm|main                     */
-  /* ..category 2|cat2overview.htm|main              */
-  /* ...item 2.1|item21.htm|main                     */
-  /* ...item 2.2|item22.htm|main                     */
-  /* ...item 2.3|item23.htm|main                     */
-  /*                                                 */  
-  /***************************************************/
 ?>
