@@ -168,9 +168,9 @@ $has_been_deleted_female_singular = "has been deleted";
 $has_been_deleted_male_singular = "has been deleted";
 $All_the_products_and_sub_categories_belonging_to = "All the products and sub-categories belonging to";
 $have_been_reassigned_to_male_plural = "have been reassigned to";
-$actually_its_name_is_male_singular = "actually its name is";
-$actually_its_name_is_female_singular = "actually its name is";
-$actually_its_value_is_female_singular = "actually its value is";
+$actually_its_name_is_male_singular = "currently its name is";
+$actually_its_name_is_female_singular = "currently its name is";
+$actually_its_value_is_female_singular = "currently its value is";
 $Add_a_subcategory_under = "Add a subcategory under";
 $Add_a_product_under = "Add a product under";
 $Edit_this_category = "Edit this category";
