@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -22,6 +22,8 @@ include("application.inc.php");
 
 /* unset the SESSION["user"] variable to log out the user */
 unset($SESSION["user"]);
+unset($SESSION["wantsurl"]);
+unset($SESSION["orderinfo"]);
 
 header("Location: $CFG->firstpage");
 ?>
