@@ -14,13 +14,12 @@ include("../application.inc.php");
 
 <table>
 <tr>
-<td class=label><?=$Categories?>:</td>
+<td class=label><a href="<?=$CFG->wwwroot?>/shopping/" target="bodyframe"><?=$Shopping?></a></td>
 </tr>
 <tr valign=top>
 <td class=normal>
 <?
 build_catbrowser($categories);
-$categories = ".Top^" . $CFG->wwwroot . "/shopping/^" . $SESSION["catbrowser_target"] . "\n" . $categories;
 require("$CFG->libdir/treemenu.inc.php");
 ?>
 </td>
