@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -50,6 +50,7 @@ function validate_form(&$frm, &$errors) {
 	$errors = new Object;
 	$msg = "";
 
+	// md5("") = d41d8cd98f00b204e9800998ecf8427e
 	if ($frm["oldpassword"] == "d41d8cd98f00b204e9800998ecf8427e") {
 		$errors->oldpassword = true;
 		$msg .= $no_old_password;
@@ -99,7 +100,7 @@ function update_password($newpassword) {
 			SET password = '$newpassword'
 			WHERE username = '$username'");
 
-	if ($SESSION["user"]["priv"] == "admin") {
+	if (has_priv("admin")) {
 		mail(
 			"$CFG->seller_fullname <$CFG->seller_email>",
 			"PgMarket root password changed",
