@@ -67,7 +67,7 @@ function validate_form(&$frm, &$errors) {
 function send_form(&$frm) {
 
 	global $CFG, $SESSION;
-	global $subject_contact, $contact;
+	global $subject_contact, $contact, $yes;
 	include ($CFG->global);
 
 	$emailbody = "";
