@@ -13,7 +13,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -52,8 +52,8 @@ function show_order_details($id, $username) {
 
 	$qid_order = db_query("
 	SELECT o.*, os.name AS state_name
-	FROM ordersca o JOIN orders_states os ON (o.state_id = os.id)
-	WHERE o.id = '$id'
+	FROM ordersca o, orders_states os
+	WHERE o.state_id = os.id AND o.id = '$id'
 	");
 	if (db_num_rows($qid_order) < 1) {
 		include("templates/no_such_order.ihtml");
@@ -69,8 +69,8 @@ function show_order_details($id, $username) {
 		,oi.weight AS purchase_weight
 		,oi.qty
 		,oi.price * oi.qty AS total
-	FROM	order_items oi JOIN products p ON (oi.product_id = p.id)
-	WHERE	order_id = '$id'
+	FROM	order_items oi, products p
+	WHERE	oi.product_id = p.id AND order_id = '$id'
 	UNION
 	SELECT
 		 oi.product_id
@@ -91,6 +91,21 @@ function show_order_details($id, $username) {
 			WHERE id = oi.product_id
 		)
 	");
+/* For MySQL
+	$qid_items = db_query("
+	SELECT
+		 oi.product_id
+		,p.name
+		,p.price AS curr_price
+		,oi.price AS purchase_price
+		,oi.iva AS purchase_iva
+		,oi.weight AS purchase_weight
+		,oi.qty
+		,oi.price * oi.qty AS total
+	FROM	order_items oi LEFT JOIN products p ON (oi.product_id = p.id)
+	WHERE	order_id = '$id'
+	");
+*/
 
 	$order = db_fetch_object($qid_order, 0);
 
@@ -117,8 +132,8 @@ function print_order_list($username) {
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
 		SELECT o.id, o.username, o.date, o.custinfo, o.amount, o.notes, os.name AS state_name
-		FROM ordersca o JOIN orders_states os ON (o.state_id = os.id)
-		WHERE username = '$username'
+		FROM ordersca o, orders_states os
+		WHERE o.state_id = os.id AND username = '$username'
 		ORDER BY os.name, o.id ASC
   		");
 
